# exponot - Reference implementation of Apple/Google COVID-19 tracing API

Exposure Notification based on docs of Apple/Google collaboration.

## References

* https://www.apple.com/covid19/contacttracing/
* https://covid19-static.cdn-apple.com/applications/covid19/current/static/contact-tracing/pdf/ExposureNotification-CryptographySpecificationv1.2.pdf
* https://pypi.org/project/pycryptodome/
* https://www.pycryptodome.org/en/latest/
* https://techtutorialsx.com/2018/04/09/python-pycrypto-using-aes-128-in-ecb-mode/
* https://laconicwolf.com/2018/07/22/cryptopals-challenge-7-implement-aes-in-ecb-mode-with-python/
* https://cryptography.io/en/latest/hazmat/primitives/key-derivation-functions/
* https://covid19-static.cdn-apple.com/applications/covid19/current/static/contact-tracing/pdf/ContactTracing-CryptographySpecification.pdf
* https://www.apple.com/covid19/contacttracing/
* https://github.com/DP-3T/documents
* https://sunblaze-ucb.github.io/privacy/papers/epione.pdf
